package java.awt.print;

import java.util.Vector;

public class Book implements Pageable
{
    private Vector mPages;
    
    public Book() {
        this.mPages = new Vector();
    }
    
    @Override
    public int getNumberOfPages() {
        return this.mPages.size();
    }
    
    @Override
    public PageFormat getPageFormat(int n) throws IndexOutOfBoundsException {
        return this.getPage(n).getPageFormat();
    }
    
    @Override
    public Printable getPrintable(int n) throws IndexOutOfBoundsException {
        return this.getPage(n).getPrintable();
    }
    
    public void setPage(int index, Printable printable, PageFormat pageFormat) throws IndexOutOfBoundsException {
        if (printable == null) {
            throw new NullPointerException("painter is null");
        }
        if (pageFormat == null) {
            throw new NullPointerException("page is null");
        }
        this.mPages.setElementAt(new Book.BookPage(printable, pageFormat), index);
        return;
    }
    
    public void append(Printable printable, PageFormat pageFormat) {
        this.mPages.addElement(new Book.BookPage(printable, pageFormat));
    }
    
    public void append(Printable printable, PageFormat pageFormat, int n) {
        Book.BookPage obj = new Book.BookPage(printable, pageFormat);
        int i = this.mPages.size();
        int size = i + n;
        this.mPages.setSize(size);
        for (; i < size; ++i) {
            this.mPages.setElementAt(obj, i);
        }
    }
    
    private Book.BookPage getPage(int index) throws ArrayIndexOutOfBoundsException {
        return (Book.BookPage)this.mPages.elementAt(index);
    }
    
    private class BookPage
    {
        private PageFormat mFormat;
        private Printable mPainter;
        
        BookPage(Printable mPainter, PageFormat mFormat) {
            if (mPainter == null || mFormat == null) {
                throw new NullPointerException();
            }
            this.mFormat = mFormat;
            this.mPainter = mPainter;
            return;
        }
        
        Printable getPrintable() {
            return this.mPainter;
        }
        
        PageFormat getPageFormat() {
            return this.mFormat;
        }
    }
}
